@@ -46,9 +46,8 @@
 #  define SORD_WRITE_LOG(...)
 #endif
 
-#define NUM_ORDERS 12
-#define STATEMENT_LEN 3
-#define TUP_LEN (STATEMENT_LEN + 1)
+#define NUM_ORDERS 12U
+#define TUP_LEN 4U
 #define DEFAULT_ORDER SPO
 #define DEFAULT_GRAPH_ORDER GSPO
 
@@ -58,7 +57,7 @@
   TUP_FMT_ELEM((t)[0]), TUP_FMT_ELEM((t)[1]), TUP_FMT_ELEM((t)[2]), \
     TUP_FMT_ELEM((t)[3])
 
-#define TUP_G 3
+#define TUP_G 3U
 
 /** Triple ordering */
 typedef enum {
@@ -96,7 +95,7 @@ static const char* const order_names[NUM_ORDERS] = {"spo",
    Quads of indices for each order, from most to least significant
    (array indexed by SordOrder)
 */
-static const int orderings[NUM_ORDERS][TUP_LEN] = {
+static const uint8_t orderings[NUM_ORDERS][TUP_LEN] = {
   {0, 1, 2, 3}, // SPO
   {0, 2, 1, 3}, // SOP
   {2, 1, 0, 3}, // OPS
@@ -147,7 +146,7 @@ struct SordIterImpl {
   SordQuad         pat;         ///< Pattern (in ordering order)
   SordOrder        order;       ///< Store order (which index)
   SearchMode       mode;        ///< Iteration mode
-  int              n_prefix;    ///< Prefix for RANGE and FILTER_RANGE
+  uint8_t          n_prefix;    ///< Prefix for RANGE and FILTER_RANGE
   bool             end;         ///< True iff reached end
   bool             skip_graphs; ///< Iteration should ignore graphs
 };
@@ -185,13 +184,13 @@ sord_node_hash(const SordNode* const node)
 static bool
 sord_node_hash_equal(const SordNode* const a, const SordNode* const b)
 {
-  return (a == b) ||
-         ((a->node.type == b->node.type) &&
-          (a->node.type != SERD_LITERAL ||
-           (a->meta.lit.datatype == b->meta.lit.datatype &&
-            !strncmp(
-              a->meta.lit.lang, b->meta.lit.lang, sizeof(a->meta.lit.lang)))) &&
-          (serd_node_equals(&a->node, &b->node)));
+  return ((a == b) || ((a->node.type == b->node.type) &&
+                       (a->node.type != SERD_LITERAL ||
+                        (a->meta.lit.datatype == b->meta.lit.datatype &&
+                         !strncmp(a->meta.lit.lang,
+                                  b->meta.lit.lang,
+                                  sizeof(a->meta.lit.lang)))) &&
+                       (serd_node_equals(&a->node, &b->node))));
 }
 
 static SordNode*
@@ -343,8 +342,10 @@ sord_id_match(const SordNode* a, const SordNode* b)
 static inline bool
 sord_quad_match_inline(const SordQuad x, const SordQuad y)
 {
-  return sord_id_match(x[0], y[0]) && sord_id_match(x[1], y[1]) &&
-         sord_id_match(x[2], y[2]) && sord_id_match(x[3], y[3]);
+  return (sord_id_match(x[0], y[0]) && //
+          sord_id_match(x[1], y[1]) && //
+          sord_id_match(x[2], y[2]) && //
+          sord_id_match(x[3], y[3]));
 }
 
 bool
@@ -361,13 +362,13 @@ sord_quad_match(const SordQuad x, const SordQuad y)
 static int
 sord_quad_compare(const void* x_ptr, const void* y_ptr, const void* user_data)
 {
-  const int* const             ordering = (const int*)user_data;
+  const uint8_t* const         ordering = (const uint8_t*)user_data;
   const SordNode* const* const x        = (const SordNode* const*)x_ptr;
   const SordNode* const* const y        = (const SordNode* const*)y_ptr;
 
-  for (int i = 0; i < TUP_LEN; ++i) {
-    const int idx = ordering[i];
-    const int cmp = sord_node_compare(x[idx], y[idx]);
+  for (uint8_t i = 0U; i < TUP_LEN; ++i) {
+    const uint8_t idx = ordering[i];
+    const int     cmp = sord_node_compare(x[idx], y[idx]);
     if (cmp) {
       return cmp;
     }
@@ -435,8 +436,8 @@ sord_iter_seek_match_range(SordIter* iter)
       return false; // Found match
     }
 
-    for (int i = 0; i < iter->n_prefix; ++i) {
-      const int idx = orderings[iter->order][i];
+    for (uint8_t i = 0U; i < iter->n_prefix; ++i) {
+      const uint8_t idx = orderings[iter->order][i];
       if (!sord_id_match(key[idx], iter->pat[idx])) {
         iter->end = true; // Reached end of valid range
         return true;
@@ -453,7 +454,7 @@ sord_iter_new(const SordModel*   sord,
               const SordQuad     pat,
               SordOrder          order,
               SearchMode         mode,
-              int                n_prefix)
+              uint8_t            n_prefix)
 {
   SordIter* iter    = (SordIter*)malloc(sizeof(SordIter));
   iter->sord        = sord;
@@ -463,7 +464,7 @@ sord_iter_new(const SordModel*   sord,
   iter->n_prefix    = n_prefix;
   iter->end         = false;
   iter->skip_graphs = order < GSPO;
-  for (int i = 0; i < TUP_LEN; ++i) {
+  for (uint8_t i = 0U; i < TUP_LEN; ++i) {
     iter->pat[i] = pat[i];
   }
 
@@ -500,14 +501,14 @@ sord_iter_new(const SordModel*   sord,
 const SordModel*
 sord_iter_get_model(SordIter* iter)
 {
-  return iter->sord;
+  return iter ? iter->sord : NULL;
 }
 
 void
 sord_iter_get(const SordIter* iter, SordQuad tup)
 {
   SordNode** key = (SordNode**)zix_btree_get(iter->cur);
-  for (int i = 0; i < TUP_LEN; ++i) {
+  for (uint8_t i = 0U; i < TUP_LEN; ++i) {
     tup[i] = key[i];
   }
 }
@@ -541,8 +542,8 @@ sord_iter_scan_next(SordIter* iter)
       // At the end if the MSNs no longer match
       key = (const SordNode**)zix_btree_get(iter->cur);
       assert(key);
-      for (int i = 0; i < iter->n_prefix; ++i) {
-        const int idx = orderings[iter->order][i];
+      for (uint8_t i = 0U; i < iter->n_prefix; ++i) {
+        const uint8_t idx = orderings[iter->order][i];
         if (!sord_id_match(key[idx], iter->pat[idx])) {
           iter->end = true;
           SORD_ITER_LOG("%p reached non-match end\n", (void*)iter);
@@ -580,7 +581,7 @@ sord_iter_scan_next(SordIter* iter)
 bool
 sord_iter_next(SordIter* iter)
 {
-  if (iter->end) {
+  if (!iter || iter->end) {
     return true;
   }
 
@@ -610,11 +611,14 @@ sord_iter_free(SordIter* iter)
    corresponding order with a G prepended (so G will be the MSN).
 */
 static inline bool
-sord_has_index(SordModel* model, SordOrder* order, int* n_prefix, bool graphs)
+sord_has_index(const SordModel* model,
+               SordOrder*       order,
+               uint8_t*         n_prefix,
+               bool             graphs)
 {
   if (graphs) {
     *order = (SordOrder)(*order + GSPO);
-    *n_prefix += 1;
+    ++*n_prefix;
   }
 
   return model->indices[*order];
@@ -628,15 +632,16 @@ sord_has_index(SordModel* model, SordOrder* order, int* n_prefix, bool graphs)
    (for `mode` == RANGE and `mode` == FILTER_RANGE)
 */
 static inline SordOrder
-sord_best_index(SordModel*     sord,
-                const SordQuad pat,
-                SearchMode*    mode,
-                int*           n_prefix)
+sord_best_index(const SordModel* sord,
+                const SordQuad   pat,
+                SearchMode*      mode,
+                uint8_t*         n_prefix)
 {
   const bool graph_search = (pat[TUP_G] != 0);
 
-  const unsigned sig = (pat[0] ? 1 : 0) * 0x100U + (pat[1] ? 1 : 0) * 0x010U +
-                       (pat[2] ? 1 : 0) * 0x001U;
+  const unsigned sig = (((pat[0] ? 1U : 0U) * 0x100U) + //
+                        ((pat[1] ? 1U : 0U) * 0x010U) + //
+                        ((pat[2] ? 1U : 0U) * 0x001U));
 
   SordOrder good[2] = {(SordOrder)-1, (SordOrder)-1};
 
@@ -650,12 +655,12 @@ sord_best_index(SordModel*     sord,
 
   // Good orderings that don't require filtering
   *mode     = RANGE;
-  *n_prefix = 0;
+  *n_prefix = 0U;
   switch (sig) {
   case 0x000:
     assert(graph_search);
     *mode     = RANGE;
-    *n_prefix = 1;
+    *n_prefix = 1U;
     return DEFAULT_GRAPH_ORDER;
   case 0x111:
     *mode = SINGLE;
@@ -697,7 +702,7 @@ sord_best_index(SordModel*     sord,
 
   if (graph_search) {
     *mode     = FILTER_RANGE;
-    *n_prefix = 1;
+    *n_prefix = 1U;
     return DEFAULT_GRAPH_ORDER;
   } else {
     *mode = FILTER_ALL;
@@ -708,27 +713,26 @@ sord_best_index(SordModel*     sord,
 SordModel*
 sord_new(SordWorld* world, unsigned indices, bool graphs)
 {
+  static const unsigned half = (NUM_ORDERS >> 1U);
+
   SordModel* model = (SordModel*)malloc(sizeof(struct SordModelImpl));
   model->world     = world;
   model->n_quads   = 0;
   model->n_iters   = 0;
 
-  for (unsigned i = 0; i < (NUM_ORDERS / 2); ++i) {
-    const int* const ordering   = orderings[i];
-    const int* const g_ordering = orderings[i + (NUM_ORDERS / 2)];
-
+  for (unsigned i = 0; i < half; ++i) {
     if (indices & (1U << i)) {
       model->indices[i] =
-        zix_btree_new(NULL, sord_quad_compare, (void*)ordering);
+        zix_btree_new(NULL, sord_quad_compare, (void*)orderings[i]);
       if (graphs) {
-        model->indices[i + (NUM_ORDERS / 2)] =
-          zix_btree_new(NULL, sord_quad_compare, (void*)g_ordering);
+        model->indices[i + half] =
+          zix_btree_new(NULL, sord_quad_compare, (void*)orderings[i + half]);
       } else {
-        model->indices[i + (NUM_ORDERS / 2)] = NULL;
+        model->indices[i + half] = NULL;
       }
     } else {
-      model->indices[i]                    = NULL;
-      model->indices[i + (NUM_ORDERS / 2)] = NULL;
+      model->indices[i]        = NULL;
+      model->indices[i + half] = NULL;
     }
   }
 
@@ -808,7 +812,7 @@ sord_free(SordModel* model)
   SordIter* i = sord_begin(model);
   for (; !sord_iter_end(i); sord_iter_next(i)) {
     sord_iter_get(i, tup);
-    for (int t = 0; t < TUP_LEN; ++t) {
+    for (uint8_t t = 0U; t < TUP_LEN; ++t) {
       sord_drop_quad_ref(model, tup[t], (SordQuadIndex)t);
     }
   }
@@ -839,7 +843,7 @@ sord_get_world(SordModel* model)
 size_t
 sord_num_quads(const SordModel* model)
 {
-  return model->n_quads;
+  return model ? model->n_quads : 0U;
 }
 
 size_t
@@ -861,17 +865,17 @@ sord_begin(const SordModel* model)
 }
 
 SordIter*
-sord_find(SordModel* model, const SordQuad pat)
+sord_find(const SordModel* model, const SordQuad pat)
 {
-  if (!pat[0] && !pat[1] && !pat[2] && !pat[3]) {
+  if (!model || (!pat[0] && !pat[1] && !pat[2] && !pat[3])) {
     return sord_begin(model);
   }
 
   SearchMode      mode        = ALL;
-  int             n_prefix    = 0;
+  uint8_t         n_prefix    = 0U;
   const SordOrder index_order = sord_best_index(model, pat, &mode, &n_prefix);
 
-  SORD_FIND_LOG("Find " TUP_FMT "  index=%s  mode=%u  n_prefix=%d\n",
+  SORD_FIND_LOG("Find " TUP_FMT "  index=%s  mode=%u  n_prefix=%u\n",
                 TUP_FMT_ARGS(pat),
                 order_names[index_order],
                 mode,
@@ -881,9 +885,9 @@ sord_find(SordModel* model, const SordQuad pat)
     mode = SINGLE; // No duplicate quads (Sord is a set)
   }
 
-  const int* const ordering = orderings[index_order];
-  ZixBTree* const  db       = model->indices[index_order];
-  ZixBTreeIter     cur      = zix_btree_end(db);
+  const uint8_t* const ordering = orderings[index_order];
+  ZixBTree* const      db       = model->indices[index_order];
+  ZixBTreeIter         cur      = zix_btree_end(db);
 
   if (mode == FILTER_ALL) {
     // No prefix shared with an index at all, linear search (worst case)
@@ -892,7 +896,7 @@ sord_find(SordModel* model, const SordQuad pat)
     /* Some prefix, but filtering still required.  Build a search pattern
        with only the prefix to find the lower bound in log time. */
     SordQuad prefix_pat = {NULL, NULL, NULL, NULL};
-    for (int i = 0; i < n_prefix; ++i) {
+    for (uint8_t i = 0U; i < n_prefix; ++i) {
       prefix_pat[ordering[i]] = pat[ordering[i]];
     }
 
@@ -918,22 +922,22 @@ sord_find(SordModel* model, const SordQuad pat)
 }
 
 SordIter*
-sord_search(SordModel*      model,
-            const SordNode* s,
-            const SordNode* p,
-            const SordNode* o,
-            const SordNode* g)
+sord_search(const SordModel* model,
+            const SordNode*  s,
+            const SordNode*  p,
+            const SordNode*  o,
+            const SordNode*  g)
 {
   SordQuad pat = {s, p, o, g};
   return sord_find(model, pat);
 }
 
 SordNode*
-sord_get(SordModel*      model,
-         const SordNode* s,
-         const SordNode* p,
-         const SordNode* o,
-         const SordNode* g)
+sord_get(const SordModel* model,
+         const SordNode*  s,
+         const SordNode*  p,
+         const SordNode*  o,
+         const SordNode*  g)
 {
   if (!!s + !!p + !!o != 2) {
     return NULL;
@@ -954,22 +958,22 @@ sord_get(SordModel*      model,
 }
 
 bool
-sord_ask(SordModel*      model,
-         const SordNode* s,
-         const SordNode* p,
-         const SordNode* o,
-         const SordNode* g)
+sord_ask(const SordModel* model,
+         const SordNode*  s,
+         const SordNode*  p,
+         const SordNode*  o,
+         const SordNode*  g)
 {
   SordQuad pat = {s, p, o, g};
   return sord_contains(model, pat);
 }
 
 uint64_t
-sord_count(SordModel*      model,
-           const SordNode* s,
-           const SordNode* p,
-           const SordNode* o,
-           const SordNode* g)
+sord_count(const SordModel* model,
+           const SordNode*  s,
+           const SordNode*  p,
+           const SordNode*  o,
+           const SordNode*  g)
 {
   SordIter* i = sord_search(model, s, p, o, g);
   uint64_t  n = 0;
@@ -981,7 +985,7 @@ sord_count(SordModel*      model,
 }
 
 bool
-sord_contains(SordModel* model, const SordQuad pat)
+sord_contains(const SordModel* model, const SordQuad pat)
 {
   SordIter* iter = sord_find(model, pat);
   bool      ret  = (iter != NULL);
@@ -1190,13 +1194,15 @@ sord_node_from_serd_node(SordWorld*      world,
     return NULL;
   case SERD_LITERAL:
     datatype_node = sord_node_from_serd_node(world, env, datatype, NULL, NULL);
-    ret           = sord_new_literal_counted(world,
+
+    ret = sord_new_literal_counted(world,
                                    datatype_node,
                                    node->buf,
                                    node->n_bytes,
                                    node->n_chars,
                                    node->flags,
                                    lang ? (const char*)lang->buf : NULL);
+
     sord_node_free(world, datatype_node);
     return ret;
   case SERD_URI:
@@ -1302,7 +1308,7 @@ sord_add(SordModel* model, const SordQuad tup)
     }
   }
 
-  for (int i = 0; i < TUP_LEN; ++i) {
+  for (uint8_t i = 0U; i < TUP_LEN; ++i) {
     sord_add_quad_ref(model, tup[i], (SordQuadIndex)i);
   }
 
@@ -1331,7 +1337,7 @@ sord_remove(SordModel* model, const SordQuad tup)
 
   free(quad);
 
-  for (int i = 0; i < TUP_LEN; ++i) {
+  for (uint8_t i = 0U; i < TUP_LEN; ++i) {
     sord_drop_quad_ref(model, tup[i], (SordQuadIndex)i);
   }
 
@@ -1368,7 +1374,7 @@ sord_erase(SordModel* model, SordIter* iter)
 
   free(quad);
 
-  for (int i = 0; i < TUP_LEN; ++i) {
+  for (uint8_t i = 0U; i < TUP_LEN; ++i) {
     sord_drop_quad_ref(model, tup[i], (SordQuadIndex)i);
   }
 
