@@ -1,9 +1,6 @@
 // Copyright 2012-2021 David Robillard <d@drobilla.net>
 // SPDX-License-Identifier: ISC
 
-#define _BSD_SOURCE 1     // for realpath
-#define _DEFAULT_SOURCE 1 // for realpath
-
 #include "sord_config.h"
 
 #include <serd/serd.h>
@@ -208,6 +205,8 @@ regexp_match(const uint8_t* const pattern, const char* const str)
   pcre2_code_free(re);
   return rc > 0;
 #else
+  (void)pattern;
+  (void)str;
   return true;
 #endif // USE_PCRE2
 }
@@ -395,13 +394,10 @@ check_type(SordModel*      model,
       return literal_is_valid(model, uris, quad, node, type);
     }
   } else if (sord_node_get_type(node) == SORD_URI) {
-    if (sord_node_equals(type, uris->foaf_Document)) {
-      return true; // Questionable...
-    } else if (is_descendant_of(
-                 model, uris, type, uris->xsd_anyURI, uris->owl_onDatatype)) {
-      /* Type is any URI and this is a URI, so pass.  Restrictions on
-         anyURI subtypes are not currently checked (very uncommon). */
-      return true; // Type is anyURI, and this is a URI
+    if (sord_node_equals(type, uris->foaf_Document) || // Questionable...
+        is_descendant_of(
+          model, uris, type, uris->xsd_anyURI, uris->owl_onDatatype)) {
+      return true; // This is a URI, and type is Document or anyUri
     } else {
       SordIter* t = sord_search(model, node, uris->rdf_type, NULL, NULL);
       for (; !sord_iter_end(t); sord_iter_next(t)) {
